% This program compiles real-time OUTCOME data from ALFRED.
% - Inflation (PIM1AL)
% - Unemployment (UM1AL)

clear all;
clc;

% INFLATION

% GNP-Deflator (quaterly), 1988:1 until 1988:2 (=2)

gnpdefvec88_1 = (xlsread('\GNPDEFmodi',2,'B161:B165'));
gnpdefvec88_2 = (xlsread('\GNPDEFmodi',2,'D163:D167'));

%PROBLEM: For the 1988-July HH-cut-off date (1988-07-07), the value for 
%the 1988-Q2 GNP Deflator is not available, one has to use the 1988-07-27 
%vintage.

gnpdeffeb = ((gnpdefvec88_1(5)/gnpdefvec88_1(1))-1)*100;
gnpdefjul = ((gnpdefvec88_2(5)/gnpdefvec88_2(1))-1)*100;
gnpdef = [gnpdeffeb; gnpdefjul];


% CPI not seasonally adjusted (monthly), 1989:1 until 1999:2 (=22)

cpifebmatrix = (xlsread('\CPIAUCNS_febr',2,'C803:M937')); % February Data
cpijulmatrix = (xlsread('\CPIAUCNS_jul',2,'C809:M942')); % July Data
cpi= 0;

for j=1:1:11
    cpifeb1(j) = mean(cpifebmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q4 two years earlier
    cpifeb2(j) = mean(cpifebmatrix(j+11*j-11+12:j+11*j-11+14,j:j)); % Q4 last year
    cpifeb(j) = ((cpifeb2(j)/cpifeb1(j))-1)*100;
    
    cpijul1(j) = mean(cpijulmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q2 last year
    cpijul2(j) = mean(cpijulmatrix(j+11*j-11+12:j+11*j-11+13,j:j)); % Q2 current year (mean of April and May)
    cpijul(j) = ((cpijul2(j)/cpijul1(j))-1)*100;
    
    cpi = [cpi; cpifeb(j); cpijul(j)];
end

cpi = cpi(2:23);


% PCE (monthly), 2000:1 until 2004:1 (=9)

%PROBLEM: First real-time vintage for PCE available from 2000-08-01,
%however one needs already data as available on 2000-02-09! Here for the
%first two vintages (2000:1 and 2000:2) 2000-08-01 is used as a proxy.

pce2000vec= (xlsread('\PCEPI_modi_jul',2,'B479:B499')); % 2000 Data (98-10 to 00-06)
pcefebmatrix = (xlsread('\PCEPI_febr',2,'B491:E541')); % February Data from 2001 on
pcejulmatrix = (xlsread('\PCEPI_modi_jul',2,'C497:E534')); % July Data from 2001 on

% for 2000
pce2000feb = (mean(pce2000vec(13:15))/mean(pce2000vec(1:3))-1)*100;
pce2000jul = (mean(pce2000vec(19:21))/mean(pce2000vec(7:9))-1)*100;
pce = [pce2000feb; pce2000jul];

% from 2001 on
for j=1:1:3
    pcefeb1(j) = mean(pcefebmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q4 two years earlier
    pcefeb2(j) = mean(pcefebmatrix(j+11*j-11+12:j+11*j-11+14,j:j)); % Q4 last year
    pcefeb(j) = ((pcefeb2(j)/pcefeb1(j))-1)*100;
    
    pcejul1(j) = mean(pcejulmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q2 last year
    pcejul2(j) = mean(pcejulmatrix(j+11*j-11+12:j+11*j-11+13,j:j)); % Q2 current year (mean of April and May)
    pcejul(j) = ((pcejul2(j)/pcejul1(j))-1)*100;
    
    pce = [pce; pcefeb(j); pcejul(j)];
end

j=4;
pcefeb1(j) = mean(pcefebmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q4 two years earlier
pcefeb2(j) = mean(pcefebmatrix(j+11*j-11+12:j+11*j-11+14,j:j)); % Q4 last year
pcefeb(j) = ((pcefeb2(j)/pcefeb1(j))-1)*100;

pce = [pce; pcefeb(4)];


% Core PCE (monthly), 2004:2 until 2007:2 (=7)
copce2004vec = (xlsread('\PCEPILFE_jul',2,'E533:E546')); % 2004 Data (2003-04 to 2004-05)
copcefebmatrix = (xlsread('\PCEPILFE_febr',2,'F539:H577')); % February Data
copcejulmatrix = (xlsread('\PCEPILFE_jul',2,'F545:H582')); % July Data

% for 2004
copce = (mean(copce2004vec(13:14))/mean(copce2004vec(1:3))-1)*100;  % 2004-July

% from 2005 on
for j=1:1:3
    copcefeb1(j) = mean(copcefebmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q4 two years earlier
    copcefeb2(j) = mean(copcefebmatrix(j+11*j-11+12:j+11*j-11+14,j:j)); % Q4 last year
    copcefeb(j) = ((copcefeb2(j)/copcefeb1(j))-1)*100;
    
    copcejul1(j) = mean(copcejulmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q2 last year
    copcejul2(j) = mean(copcejulmatrix(j+11*j-11+12:j+11*j-11+13,j:j)); % Q2 current year (mean of April and May)
    copcejul(j) = ((copcejul2(j)/copcejul1(j))-1)*100;
    
    copce = [copce; copcefeb(j); copcejul(j)];
end


% Outcome Inflation Series from ALFRED:

PIM1AL = [gnpdef; cpi; pce; copce;];

% Save:
xlswrite('outcome_data_alfred.xls',PIM1AL,1,'B4:B43');


% UNEMPLOYMENT RATE (=40)

unfebmatrix = (xlsread('\UNRATE_febr',2,'B479:U709')); % Febr-Data
unjulmatrix = (xlsread('\UNRATE_jul',2,'B485:U714')); % July-Data
un = 0;

for j=1:1:19
    unfeb(j) = mean(unfebmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q4 last year (mean of Oct,Nov,Dec)
    
    test_unjul = isnan(unjulmatrix(j+11*j-11+2,j)); % Test whether data for June exists
    if test_unjul == 1  %if NO data for June exists:
    unjul(j) = mean(unjulmatrix(j+11*j-11:j+11*j-11+1,j:j)); % Q2 current year = mean of Apr,May
    else unjul(j) = mean(unjulmatrix(j+11*j-11:j+11*j-11+2,j:j)); % if data for june exists: mean of Apr,May,June
    end
    un = [un; unfeb(j); unjul(j);];
end
% Comment: The test can only be applied for j<20 because at j=20 the
% index would exceed the matrix bounds

j=20; 
unfeb(j) = mean(unfebmatrix(j+11*j-11:j+11*j-11+2,j:j)); % Q4 2006 = mean of Oct,Nov,Dec
unjul(j) = mean(unjulmatrix(j+11*j-11:j+11*j-11+1,j:j)); % Q2 2007 = mean of Apr,May 

UM1AL = [un(2:39); unfeb(20); unjul(20);];

% Save:
xlswrite('outcome_data_alfred.xls',UM1AL,1,'C4:C43');


