% This program calculates real-time annualized inflation rate outcomes for 
% the first half of every year from ALFRED data. 
% (Required to construct july hh-forecasts for inflation)


clear all;
clc;

% GNP Deflator
gnpcolumn= (xlsread('\GNPDEF_3',2,'C165:C167'));


%Load July-Vintage-Files for CPI: 1994 - 1999 (=11 observations)
%NOT SEASONALIZED!
%load Q4 TO Q2 Data  (JUNE prior to 94 ex post) 
cpimatrix= (xlsread('\CPIAUCNS_2',2,'C815:M942'));


%Load July-Vintage-Files for PCE: 2000 - 2003 (=4 observations)
%PROBLEM: First real-time vintage for PCE available from 2000-08-01,
%however one needs already data as available on 2000-07-05! Here for the
%first vintage 2000-08-01 is used as a proxy.

%load Q4 TO MAY Data 
pcematrix= (xlsread('\PCEPI_3',2,'B491:E534'));


%Load July-Vintage-Files for Core PCE 2004 - 2007 (=4 observations)
%load Q4 TO MAY Data 
copcematrix= (xlsread('\PCEPILFE_3',2,'E539:H582'));


% 2) CALCULATE INFLATION RATES

% Real-time GNP- Inflation, Q4-Q2
gnpdef=((gnpcolumn(3)./gnpcolumn(1))^(4/2)-1)*100;


%Real-time CPI-Inflation, DECEMBER-May, annualized for 1995 - 1999
for j=1:1:11
    cpiq4=mean(cpimatrix(j+11*j-11:j+11*j-11+2,j:j));
    cpiq2=mean(cpimatrix(j+11*j-11+6:j+11*j-11+7,j:j));
         cpi(j)=((cpiq2./cpiq4)^(4/2)-1)*100;
end

%Real-time PCE-Inflation, Januar-May, annualized for 2000-2003 (Jan-Jun in
% 2000)
j=1;
    pceq4=mean(pcematrix(j+11*j-11:j+11*j-11+2,j:j));
    pceq2=mean(pcematrix(j+11*j-11+6:j+11*j-11+8,j:j));
         pce(j)=((pceq2./pceq4)^(4/2)-1)*100;

for j=2:1:4
    pceq4=mean(pcematrix(j+11*j-11:j+11*j-11+2,j:j));
    pceq2=mean(pcematrix(j+11*j-11+6:j+11*j-11+7,j:j));
         pce(j)=((pceq2./pceq4)^(4/2)-1)*100;
end

%Real-time Core-PCE-Inflation, Januar-May, annualized for 2004-2007
for j=1:1:4
    copceq4=mean(copcematrix(j+11*j-11:j+11*j-11+2,j:j));
    copceq2=mean(copcematrix(j+11*j-11+6:j+11*j-11+7,j:j));
         copce(j)=((copceq2./copceq4)^(4/2)-1)*100;
end

% 3) COMBINE DATA SERIES AND SAVE IT IN pim1halfalq4.xls

PIM1HALFALQ4 =[gnpdef cpi pce copce]';

rowindexhelp = (5:1:43)';
rowindex = num2str(rowindexhelp);
colindex = char('B');

T = length(PIM1HALFALQ4);

for j = 1:1:T;
    rowcolindexj = [colindex rowindex(-1+2*j,:)];
    xlswrite('pim1halfalq4.xls',PIM1HALFALQ4(j),1,rowcolindexj);
end;


