* Orphanides, Wieland (2008)
* Economic Projections and Rules of Thumb for Monetary Policy


* This file produces the regression results reported in the paper (i.e. table 3 and 4).


*==================================================================
* LOAD DATA
*==================================================================

calendar 1987 1 2
allocate 2007:2

open data hhdata_extract.xls
data(format=xls,org=columns)


*===================================================================
* DESCRIPTION OF DATA SERIES
*===================================================================

*PINEXTYEAR:
*Inflation forecast for the respective subsequent year, from the July HH-Reports
*(mean of central tendency).

*PIJCM:
*Inflation forecast for the respective current year, from the July HH-Reports
*(mean of central tendency).

*PIFCM:
*Inflation forecast for the current year from the Februar HH-Reports
*(mean of central tendency).

*PIM1HALFALQ4: Annualized real-time inflation rates for the first half of each year,
*more precisely for Q4 to Q2  (mostly only april and may data is available for Q2)
*data from ALFRED. Until 1999:2 CPI data is employed (not seasonalized till 94), then
*until 2003:2 PCE and from 2004:2 onwards Core PCE.

*PIM1HALFGB:
*Annualized real-time inflation rates for the first half of each year,
*data taken from Greenbooks. For the first
*observation (1988:2) the GNP Deflator is used, then until 1999:2 CPI
*and from 2000:2 PCE, data ends at 2001:2.

*PIM1HALFGBAL:
*adds the AL based calculations from 2002:2 onwards where Greenbooks are not available.

*PI3HH_GBAL: (ALSO COMPUTED AGAIN FROM SCRATCH FURTHER BELOW)
*HH-forecast of inflation for 3 periods ahead (t+3). For the forecast in
*February (YYYY:1), the forecast from the Februar HH-Report for the Q4/Q4 inflation i.e. till
*fourth quarter of the current year is used (mean of central tendency).
*For the forecast in July (YYYY:2), (july is the third quarter)one needs to calculate the Q2 current year
*to Q2 next year forecast. Available is the Q4Q4 forecast for the current year and for
*the next year.  First step, compute outcome for first half of year (from GREENBOOK data, or from ALFRED data)
*and then substract first half of year estimate from full year forecast, to get second half of year
*forecast. Use forcast for all of next year, as forecast of first half of next year.

*UNEXTYEAR:
*Unemployment forecast for Q4 of the respective subsequent year, from the July HH-Reports
*(mean of central tendency).

*UJCM:
*Unemployment forecast for Q4 of the respective current year, from the July HH-Reports
*(mean of central tendency).

*UFCM:
*Unemployment forecast for Q4 of the respective current year, from the Februar HH-Reports
*(mean of central tendency).

*U3HH:(ALSO COMPUTED AGAIN FROM SCRATCH FURTHER BELOW)
*HH-forecast of unemployment for 3 periods ahead (t+3). For the forecast in
*February (YYYY:1), the forecast from the Februar HH-Report for the fourth quarter
*of the current year is used (mean of central tendency).
*For the forecast in July (YYYY:2), the mean of the forecast for the fourth quarter of
*the current year (t+1) and for the fourth quarter of the subsequent year (t+5) from
*the July HH-Report is used.

*PIM1GB:
*Real-time inflation outcome (t-1). For YYYY:1 (February) the 4 quarter inflation rate
*of Q4 of the previous year has to be used. This value can be found in the January Greenbooks.
*For YYYY:2 (July) the 4 quarter inflation rate of Q2 of the current year has to be used.
*This variable is constructed as geometric mean of the annualized one-quarter inflation rates
*of Q3 and and Q4 of the previous year and Q1 and Q2 of the current year, as reported in the
*respective June Greenbooks. (see outcome.xls) Equivalent to the HH-forecasts, until 1988:2
*the GNP-Deflator is used, then from 1989:1 until 1999:2 CPI and from
*then onwards PCE. Series ends at 2001:2.

*PIM1AL:
*Real-time inflation outcome (t-1). Same definition as PIM1GB using data from ALFRED
*instead of Greenbook data. Equivalent to the HH-forecasts, until 1988:2
*the GNP-Deflator is used, then from 1989:1 until 1999:2 CPI, then from 2000:1
*until 2004:1 PCE and from 2004:2 onwards Core PCE.

*PIM1_GBAL:
*adds the AL based calculations from 2002:1 onwards where Greenbooks are not available.

*UM1GB:
*Real-time unemployment rate outcome (t-1). For YYYY:1 (February) the respective unemployment
*rate for Q4 of the previous year is selected from the January Greenbooks. For YYYY:2 (July)
*the respective unemployment rate for Q2 of the current year is selected from the June Greenbooks.
*Series ends at 2001:2.

*UM1AL:
*Real-time unemployment rate outcome (t-1).Same definition as UM1GB using data from ALFRED
*instead of Greenbook data.

*UM1_GBAL:
*adds the AL based calculations from 2002:1 onwards where Greenbooks are not available.

*RFFX:
*The intended federal funds rate that prevailed at the time of the
*HH-Report publication, respectively.


* Define seasonal dummies to denote july data and february data
seasonal july
set febr = 1-july


*=============================================================
* DATA CONSTRUCTION
*==============================================================

* GBAL) GB + AL VERSION:
* Create first-half year inflation using available Greenbook data extended with AL data from 01 onwards.
*
* Note this uses AL data from 01 onwards i.e. PCE and 04 onwards Core PCE


* Inflation forecast pi3hh:

set pi2ndhalf_gbal = 2*PIJCM - PIM1HALFGBAL
set pi3julyhh_gbal = 0.5*(pi2ndhalf_gbal + PINEXTYEAR)
set pi3hh_gbal = PIFCM*febr + pi3julyhh_gbal*july
set pi3hh_gbal = %if(febr,PIFCM,pi3hh_gbal)
set pi3hh = pi3hh_gbal

* Unemployment forecast u3hh:

set u3julyhh = 0.5*(UJCM+UNEXTYEAR)
set u3hh = UFCM*febr + u3julyhh*july
set u3hh = %if(febr,UFCM,u3hh)


*=============================================================
* SPECIFY POLICY RULES
*=============================================================

* OUTCOME-BASED RULES
compute a0=au=ap=aq=rho=0.0
frml rffxeq_outcomes rffx = rho*rffx(t-1) + (1-rho)*(a0 + ap*pim1_gbal + au*um1_gbal)

* FORECAST-BASED RULES
compute a0=au=ap=rho=0.0
frml rffxeq_forecasts rffx = rho*rffx(t-1) + (1-rho)*(a0 + ap*pi3hh + au*u3hh)



* +++++++++++++++++++++++++
* REGRESSIONS
* +++++++++++++++++++++++++

*=============================================================
* OW2008 TABLE 3: Outcomes versus FOMC Forecasts 1988:1-2007:2
*=============================================================

* Period of CPI, PCE and core PCE i.e. 1988 - 2007

*-------------------------------------------------------
* COLUMN 1: Outcomes, without interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au
nlls(frml=rffxeq_outcomes,iterations = 30) rffx 1988:1 2007:2


*-------------------------------------------------------
* COLUMN 2: Outcomes, with Interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au rho
nlls(frml=rffxeq_outcomes,iterations = 30) rffx 1988:1 2007:2


*-------------------------------------------------------
* COLUMN 3: Forecasts, without interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au
nlls(frml=rffxeq_forecasts,iterations = 30) rffx 1988:1 2007:2


*-------------------------------------------------------
* COLUMN 4: Forecasts, with interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au rho
nlls(frml=rffxeq_forecasts,iterations = 30) rffx 1988:1 2007:2



*=================================================================================
* OW2008 TABLE 4: Period with FOMC Forecasts regarding CPI Inflation: 1988-1999
*=================================================================================

*-------------------------------------------------------
* COLUMN 1: Outcomes, without interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au
nlls(frml=rffxeq_outcomes,iterations = 30) rffx 1988:1 1999:2


*-------------------------------------------------------
* COLUMN 2: Outcomes, with Interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au rho
nlls(frml=rffxeq_outcomes,iterations = 30) rffx 1988:1 1999:2


*-------------------------------------------------------
* COLUMN 3: Forecasts, without interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au
nlls(frml=rffxeq_forecasts,iterations = 30) rffx 1988:1 1999:2


*-------------------------------------------------------
* COLUMN 4: Forecasts, with interest rate smoothing
*-------------------------------------------------------

compute a0=au=ap=rho=0.0
nonlin a0 ap au rho
nlls(frml=rffxeq_forecasts,iterations = 30) rffx 1988:1 1999:2


